@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2021 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2022 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -152,7 +152,6 @@ class RegistryImporter(RegistrySession, WithBlobs):
 
         Raises:
             ValueError: Unsupported media type.
-            HTTPError: HTTP Error.
         """
         stats = ImportStats()
         if manifest_name is None:
@@ -164,8 +163,6 @@ class RegistryImporter(RegistrySession, WithBlobs):
         try:
             source_mime_type = source.mime_type
         except HTTPError as err:
-            if err.response.status_code != codes['not_found']:
-                raise err
             logger.warning(  # noqa: G200
                 '%s%s NOT imported as %s:%s: %s',
                 log_prefix,
