@@ -44,6 +44,11 @@ class GitLabracadabraApplicationSettings(GitLabracadabraObject):
                 '_doc_link': 'action_file.md#gitlab_id',
             },
             # From https://docs.gitlab.com/ee/api/settings.html#list-of-settings-that-can-be-accessed-via-api-calls
+            'admin_mode': {
+                'type': 'boolean',
+                'description': 'Require administrators to enable Admin Mode by re-authenticating for administrative '
+                               'tasks.',
+            },
             'admin_notification_email': {
                 'type': 'string',
                 'description': 'Abuse reports will be sent to this address if it is set. Abuse reports are always '
@@ -97,6 +102,11 @@ class GitLabracadabraApplicationSettings(GitLabracadabraObject):
                 'description': 'Enable Auto DevOps for projects by default. It will automatically build, test, and '
                                'deploy applications based on a predefined CI/CD configuration.',
             },
+            'can_create_group': {
+                'type': 'boolean',
+                'description': 'Indicates whether users can create top-level groups. Introduced in GitLab 15.5. '
+                               'Defaults to true.',
+            },
             'check_namespace_plan': {  # >= PREMIUM, SILVER
                 'type': 'boolean',
                 'description': 'Enabling this will make only licensed EE features available to projects if the project '
