@@ -1141,9 +1141,9 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                     'additionalProperties': False,
                 },
                 '_example': ('\n'
-                             '    # Mirror debian:buster\n'
-                             '    # ... to registry.example.org/mygroup/myproject/library/debian:buster:\n'
-                             "    - from: 'debian:buster'\n"
+                             '    # Mirror debian:bullseye\n'
+                             '    # ... to registry.example.org/mygroup/myproject/library/debian:bullseye:\n'
+                             "    - from: 'debian:bullseye'\n"
                              '    # Overriding destination:\n'
                              "    - from: 'quay.org/coreos/etcd:v3.4.1'\n"
                              "      to: 'etcd:v3.4.1' # Default would be coreos/etcd:v3.4.1\n"),
