@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2021 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2022 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -21,13 +21,13 @@ from logging import getLogger
 from typing import Optional
 from urllib.parse import urljoin
 
-from requests import Session, codes
-from requests.adapters import HTTPAdapter
+from requests import codes
 from yaml import safe_load as yaml_safe_load
 
 from gitlabracadabra.matchers import Matcher
 from gitlabracadabra.packages.package_file import PackageFile
 from gitlabracadabra.packages.source import Source
+from gitlabracadabra.session import Session
 
 
 logger = getLogger(__name__)
@@ -67,8 +67,6 @@ class Helm(Source):
         self._channel = channel or 'stable'
 
         self._session = Session()
-        self._session.mount('http://', HTTPAdapter(max_retries=3))
-        self._session.mount('https://', HTTPAdapter(max_retries=3))
 
     def __str__(self) -> str:
         """Return string representation.
@@ -108,7 +106,7 @@ class Helm(Source):
             for match in matches:
                 package_files.append(self._package_file(package_versions[match[0]]))
         if not package_files:
-            logger.info(
+            logger.warning(
                 '%sPackage not found %s for Helm index %s',
                 self._log_prefix,
                 self._package_name,
