@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2021 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2022 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -28,13 +28,13 @@ from html5lib import parse as html5lib_parse
 from packaging.requirements import InvalidRequirement, Requirement
 from packaging.utils import canonicalize_name
 from packaging.version import InvalidVersion, Version
-from requests import Session, codes
-from requests.adapters import HTTPAdapter
+from requests import codes
 from requests.models import Response
 
 from gitlabracadabra.packages.package_file import PackageFile
 from gitlabracadabra.packages.pip import extract_version_from_fragment
 from gitlabracadabra.packages.source import Source
+from gitlabracadabra.session import Session
 
 
 try:
@@ -71,8 +71,6 @@ class PyPI(Source):
             self._requirements = [req for reqs in requirements for req in reqs.splitlines()]
 
         self._session = Session()
-        self._session.mount('http://', HTTPAdapter(max_retries=3))
-        self._session.mount('https://', HTTPAdapter(max_retries=3))
 
     def __str__(self) -> str:
         """Return string representation.
