@@ -35,7 +35,7 @@ class TestApplicationSettings(TestCaseWithManager):
         # ApplicationSetting.first.delete
         obj = GitLabracadabraApplicationSettings('memory', 'application_settings', {
             # 'abuse_notification_email': 'some string',
-            # 'admin_mode': True,
+            'admin_mode': False,
             'after_sign_out_path': 'https://example.org/sign_out',
             'after_sign_up_text': 'some string',
             'akismet_api_key': 'some string',
@@ -52,6 +52,7 @@ class TestApplicationSettings(TestCaseWithManager):
             'auto_devops_domain': 'autodevops.example.org',
             'auto_devops_enabled': True,
             # 'automatic_purchased_storage_allocation': True,
+            'can_create_group': True,
             'check_namespace_plan': True,
             'commit_email_hostname': 'users.noreply.127.0.0.1',
             # 'container_expiration_policies_enable_historic_entries': True,
