@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2021 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2022 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -25,39 +25,39 @@ from gitlabracadabra.matchers import Matcher
 from gitlabracadabra.tests.case import TestCaseWithManager
 
 
-TestData = namedtuple('TestData', ['patterns', 'as_callable', 'result', 'called'])
-TestDataSemVer = namedtuple('TestDataSemVer', ['patterns', 'semver', 'result', 'called'])
+FixtureData = namedtuple('FixtureData', ['patterns', 'as_callable', 'result', 'called'])
+FixtureDataSemVer = namedtuple('FixtureDataSemVer', ['patterns', 'semver', 'result', 'called'])
 
 INPUT_DATA = ('item', 'item_suffix', 'prefix_item', 'another')
 
 TEST_DATA = (
     # String patterns
-    TestData('item', as_callable=False, result=['item'], called=None),
-    TestData('item', as_callable=True, result=['item'], called=False),
-    TestData(['item', 'extra'], as_callable=False, result=['item'], called=None),
-    TestData(['item', 'extra'], as_callable=True, result=['item', 'extra'], called=False),
+    FixtureData('item', as_callable=False, result=['item'], called=None),
+    FixtureData('item', as_callable=True, result=['item'], called=False),
+    FixtureData(['item', 'extra'], as_callable=False, result=['item'], called=None),
+    FixtureData(['item', 'extra'], as_callable=True, result=['item', 'extra'], called=False),
     # Regex patterns
-    TestData('/item/', as_callable=False, result=['item'], called=None),
-    TestData('/item/', as_callable=True, result=['item'], called=True),
-    TestData(['/item/', '/extra/'], as_callable=False, result=['item'], called=None),
-    TestData(['/item/', '/extra/'], as_callable=True, result=['item'], called=True),
+    FixtureData('/item/', as_callable=False, result=['item'], called=None),
+    FixtureData('/item/', as_callable=True, result=['item'], called=True),
+    FixtureData(['/item/', '/extra/'], as_callable=False, result=['item'], called=None),
+    FixtureData(['/item/', '/extra/'], as_callable=True, result=['item'], called=True),
     # Mixed patterns
-    TestData(['another', '/item.*/'], as_callable=False, result=['item', 'item_suffix', 'another'], called=None),
-    TestData(['another', '/item.*/'], as_callable=True, result=['item', 'item_suffix', 'another'], called=True),
-    TestData(['another', '/.*item/'], as_callable=False, result=['item', 'prefix_item', 'another'], called=None),
-    TestData(['another', '/.*item/'], as_callable=True, result=['item', 'prefix_item', 'another'], called=True),
+    FixtureData(['another', '/item.*/'], as_callable=False, result=['item', 'item_suffix', 'another'], called=None),
+    FixtureData(['another', '/item.*/'], as_callable=True, result=['item', 'item_suffix', 'another'], called=True),
+    FixtureData(['another', '/.*item/'], as_callable=False, result=['item', 'prefix_item', 'another'], called=None),
+    FixtureData(['another', '/.*item/'], as_callable=True, result=['item', 'prefix_item', 'another'], called=True),
     # Flags
-    TestData('/Item/', as_callable=False, result=[], called=None),
-    TestData('/Item/i', as_callable=False, result=['item'], called=None),
+    FixtureData('/Item/', as_callable=False, result=[], called=None),
+    FixtureData('/Item/i', as_callable=False, result=['item'], called=None),
 )
 
 
 INPUT_DATA_SEMVER = ('v1.20.4', 'v1.20.5', 'v1.20.6', 'v1.21.0')
 
 TEST_DATA_SEMVER = (
-    TestDataSemVer(['/v.*/'], '>=1.20.5', ['v1.20.5', 'v1.20.6', 'v1.21.0'], called=True),
-    TestDataSemVer(['/v.*/', 'v1.0'], '>=1.20.5', ['v1.20.5', 'v1.20.6', 'v1.21.0'], called=True),
-    TestDataSemVer(['v1.0', 'v2.0'], '>=1.20.5', ['v1.0', 'v2.0'], called=False),
+    FixtureDataSemVer(['/v.*/'], '>=1.20.5', ['v1.20.5', 'v1.20.6', 'v1.21.0'], called=True),
+    FixtureDataSemVer(['/v.*/', 'v1.0'], '>=1.20.5', ['v1.20.5', 'v1.20.6', 'v1.21.0'], called=True),
+    FixtureDataSemVer(['v1.0', 'v2.0'], '>=1.20.5', ['v1.0', 'v2.0'], called=False),
 )
 
 
