@@ -33,8 +33,7 @@ class TestParser(TestCase):
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
-            d = {k: v for k, v in p._items()}
-            self.assertEqual(d, {'message': {'hello': 'world'}})
+            self.assertEqual(dict(p._items()), {'message': {'hello': 'world'}})
 
     def test_include_str(self):
         contents_map = {
@@ -49,8 +48,7 @@ class TestParser(TestCase):
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
-            d = {k: v for k, v in p._items()}
-            self.assertEqual(d, {'message': {'hello': 'world'}})
+            self.assertEqual(dict(p._items()), {'message': {'hello': 'world'}})
 
     def test_include_local(self):
         contents_map = {
@@ -65,8 +63,7 @@ class TestParser(TestCase):
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
-            d = {k: v for k, v in p._items()}
-            self.assertEqual(d, {'message': {'hello': 'world'}})
+            self.assertEqual(dict(p._items()), {'message': {'hello': 'world'}})
 
     def test_include_recursion(self):
         contents_map = {
@@ -82,7 +79,7 @@ class TestParser(TestCase):
         with patch_open(contents_map):
             with self.assertRaises(ValueError) as cm:
                 p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
-                {k: v for k, v in p._items()}
+                dict(p._items())
 
         self.assertEqual(str(cm.exception), 'gitlabracadabra.yml: nesting too deep in `include`')
 
@@ -96,7 +93,7 @@ class TestParser(TestCase):
         with patch_open(contents_map):
             with self.assertRaises(ValueError) as cm:
                 p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
-                {k: v for k, v in p._items()}
+                dict(p._items())
 
         self.assertEqual(str(cm.exception), 'gitlabracadabra.yml: forbidden path for `include`: ../included.yml')
 
@@ -110,7 +107,7 @@ class TestParser(TestCase):
         with patch_open(contents_map):
             with self.assertRaises(ValueError) as cm:
                 p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
-                {k: v for k, v in p._items()}
+                dict(p._items())
 
         self.assertEqual(str(cm.exception), 'gitlabracadabra.yml: forbidden path for `include`: /included.yml')
 
@@ -125,7 +122,7 @@ class TestParser(TestCase):
             another-key:
               param4: value4
             """)
-        d = {k: v for k, v in p._items()}
+        d = dict(p._items())
 
         self.assertNotIn('.hidden-key', d)
         self.assertIn('shown-key', d)
@@ -139,7 +136,7 @@ class TestParser(TestCase):
                 - key1
             """)
         with self.assertRaises(ValueError) as cm:
-            {k: v for k, v in p._items()}
+            dict(p._items())
 
         self.assertEqual(str(cm.exception), '- (`key1` from `key2`): key1 not found')
 
@@ -156,7 +153,7 @@ class TestParser(TestCase):
               foo3: bar3
             """)
         with self.assertRaises(ValueError) as cm:
-            {k: v for k, v in p._items()}
+            dict(p._items())
 
         self.assertEqual(str(cm.exception), '- (key1): nesting too deep in `extends`')
 
@@ -169,7 +166,7 @@ class TestParser(TestCase):
                 - key1: keep-the-best
             """)
         with self.assertRaises(ValueError) as cm:
-            {k: v for k, v in p._items()}
+            dict(p._items())
 
         self.assertEqual(str(cm.exception), '- (`key1` from `key2`): Unknown merge strategy `keep-the-best`')
 
@@ -204,7 +201,7 @@ class TestParser(TestCase):
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
-            d = {k: v for k, v in p._items()}
+            d = dict(p._items())
 
         self.assertNotIn('.e1', d)
         self.assertNotIn('include', d)
@@ -250,7 +247,7 @@ class TestParser(TestCase):
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
-            d = {k: v for k, v in p._items()}
+            d = dict(p._items())
 
         self.assertNotIn('.e1', d)
         self.assertNotIn('include', d)
@@ -296,7 +293,7 @@ class TestParser(TestCase):
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
-            d = {k: v for k, v in p._items()}
+            d = dict(p._items())
 
         self.assertNotIn('.e1', d)
         self.assertNotIn('include', d)
