@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2020 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2022 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -30,41 +30,41 @@ from gitlabracadabra.tests.case import TestCaseWithManager
 
 VERIFY_DIGEST_METHOD = '_verify_digest'
 
-TestData = namedtuple('TestData', ['mirrors', 'mappings'])
+FixtureData = namedtuple('FixtureData', ['mirrors', 'mappings'])
 
 TEST_DATA = (
-    TestData(
+    FixtureData(
         [{'from': 'debian'}],
         (('docker.io/library/debian:latest', 'mygroup/myproject/library/debian:latest'),),
     ),
-    TestData(
+    FixtureData(
         [{'from': 'debian:buster'}],
         (('docker.io/library/debian:buster', 'mygroup/myproject/library/debian:buster'),),
     ),
-    TestData(
+    FixtureData(
         [{'from': 'debian:buster', 'to': ''}],
         (('docker.io/library/debian:buster', 'mygroup/myproject:buster'),),
     ),
-    TestData(
+    FixtureData(
         [{'from': 'debian:buster', 'to': ':latest'}],
         (('docker.io/library/debian:buster', 'mygroup/myproject:latest'),),
     ),
-    TestData(
+    FixtureData(
         [{'from': 'quay.org/coreos/etcd:v3.4.1', 'to': 'etcd:v3.4.1'}],
         (('quay.org/coreos/etcd:v3.4.1', 'mygroup/myproject/etcd:v3.4.1'),),
     ),
-    TestData(
+    FixtureData(
         [{'from': {'repositories': ['a']}, 'to': 'etcd:v3.4.1'}],
         (('docker.io/library/a:latest', 'mygroup/myproject/etcd:v3.4.1'),),
     ),
-    TestData(
+    FixtureData(
         [{'from': {'repositories': ['a', 'b']}, 'to': 'etcd:v3.4.1'}],
         (
             ('docker.io/library/a:latest', 'mygroup/myproject/etcd:v3.4.1'),
             ('docker.io/library/b:latest', 'mygroup/myproject/etcd:v3.4.1'),
         ),
     ),
-    TestData(
+    FixtureData(
         [{'from': {
             'base': 'k8s.gcr.io/kubernetes',
             'repositories': ['kube-apiserver', 'kube-proxy'],
@@ -77,7 +77,7 @@ TEST_DATA = (
             ('k8s.gcr.io/kubernetes/kube-proxy:v1.20.6', 'mygroup/myproject/kubernetes/kube-proxy:v1.20.6'),
         ),
     ),
-    TestData(
+    FixtureData(
         [{
             'from': {
                 'base': 'k8s.gcr.io/kubernetes',
@@ -93,7 +93,7 @@ TEST_DATA = (
             ('k8s.gcr.io/kubernetes/kube-proxy:v1.20.6', 'mygroup/myproject/k8s.gcr.io/kubernetes/kube-proxy:v1.20.6'),
         ),
     ),
-    TestData(
+    FixtureData(
         [{
             'from': {
                 'base': 'k8s.gcr.io/kubernetes',
@@ -111,7 +111,7 @@ TEST_DATA = (
             ('k8s.gcr.io/kubernetes/kube-proxy:v1.20.6', 'mygroup/myproject/new_base/kube-proxy:v1.20.6'),
         ),
     ),
-    TestData(
+    FixtureData(
         [{
             'from': {
                 'base': 'k8s.gcr.io/kubernetes',
@@ -129,7 +129,7 @@ TEST_DATA = (
             ('k8s.gcr.io/kubernetes/kube-proxy:v1.20.6', 'mygroup/myproject/k8s.gcr.io/kubernetes/new_repo:v1.20.6'),
         ),
     ),
-    TestData(
+    FixtureData(
         [{
             'from': {
                 'base': 'k8s.gcr.io/kubernetes',
@@ -148,7 +148,7 @@ TEST_DATA = (
         ),
     ),
     # Regexps
-    TestData(
+    FixtureData(
         [{
             'from': {
                 'repositories': ['busybox', 'debian'],
@@ -166,7 +166,7 @@ TEST_DATA = (
             ('docker.io/library/debian:unstable', 'mygroup/myproject/debian:how-uns-table'),
         ),
     ),
-    TestData(
+    FixtureData(
         [{
             'from': 'busybox:/(uns|s)(id|table)/',
         }],
@@ -175,7 +175,7 @@ TEST_DATA = (
             ('docker.io/library/busybox:unstable', 'mygroup/myproject/library/busybox:unstable'),
         ),
     ),
-    TestData(
+    FixtureData(
         [{
             'from': 'busybox:/(uns|s)(id|table)/',
             'to': {
@@ -188,7 +188,7 @@ TEST_DATA = (
         ),
     ),
     # Semver
-    TestData(
+    FixtureData(
         [{
             'from': 'k8s.gcr.io/kubernetes/kube-apiserver',
             'semver': '>=1.20.5',
@@ -241,6 +241,7 @@ class TestProjectImageMirrors(TestCaseWithManager):
             verify_digest_mock.return_value = None
             project = GitLabracadabraProject('memory', 'root/test_registry', {
                 'image_mirrors': [{
+                    'enabled': True,
                     'from': 'busybox',
                     'to': 'busybox',
                 }],
@@ -385,6 +386,37 @@ class TestProjectImageMirrors(TestCaseWithManager):
                 )])
         self.assertTrue(cass.all_played)
 
+    @my_vcr.use_cassette
+    def test_image_mirrors_redirect(self, cass):
+        """Test image_mirrors, with redirect.
+
+        Args:
+            cass: VCR cassette.
+        """
+        expected_digest = 'sha256:4fd21f36075b44d1a423dfb262ad79202ce54e95f5cbc4622a6c1c38ab287ad6'
+        with patch.object(WithDigest, VERIFY_DIGEST_METHOD) as verify_digest_mock:
+            verify_digest_mock.return_value = None
+            project = GitLabracadabraProject('memory', 'root/test-registry', {
+                'image_mirrors': [
+                    {'from': 'registry.k8s.io/sig-storage/csi-node-driver-registrar:v2.5.0'},
+                ],
+            })
+            self.assertEqual(project.errors(), [])
+            with patch('gitlabracadabra.containers.registry_importer.logger', autospec=True) as logger:
+                project.process()
+                logger.info.assert_has_calls([call(
+                    '%s%s %simported as %s:%s (%s, %s, %s)',
+                    '[root/test-registry] ',
+                    'registry.k8s.io/sig-storage/csi-node-driver-registrar:v2.5.0@{0}'.format(expected_digest),
+                    '',
+                    'root/test-registry/sig-storage/csi-node-driver-registrar',
+                    'v2.5.0',
+                    '1+0=1 uploaded+existing manifests',
+                    '3+0+0=3 uploaded+mounted+existing blobs',
+                    '9128096+0+0=9128096 uploaded+mounted+existing blobs size',
+                )])
+        self.assertTrue(cass.all_played)
+
     def _assert_mappings(self, registry, import_manifest_mock, mappings):
         self.assertEqual(len(import_manifest_mock.mock_calls), len(mappings))
         for mapping_index, mapping in enumerate(mappings):
