@@ -166,6 +166,9 @@ class TestProjectPackageMirrors(TestCaseWithManager):
                         'v0.18.1',
                     ),
                 ])
+        # https://api.github.com/repos/operator-framework/operator-lifecycle-manager/releases/42498775/assets
+        # is not called with pygithub >= v1.58.0
+        cass.play_counts[2] = 1
         self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
